Optional module supporting async loading with futures traits.
The functions in this module are drop-in replacements for the standard non-async functions in this crate, but tailored to use futures AsyncRead traits.
While futures provides basic read/write async traits, it does not
provide filesystem IO implementations for these traits, so this module only
contains *_buf() variants of this crate’s functions.
Functions
- load_
mtl_ buf - Asynchronously load the various materials in a
MTLbuffer. - load_
obj_ buf - Asynchronously load the various meshes in an ‘OBJ’ buffer.