Struct tobj::Model
[−]
[src]
pub struct Model {
pub mesh: Mesh,
pub name: String,
}A named model within the file, associates some mesh with a name that was specified with an o
or g keyword in the OBJ file
Fields
mesh: Mesh
Mesh used by the model containing its geometry
name: String
Name assigned to this mesh